@@ -17,7 +17,7 @@ double Usermainalgebraics(gsl_vector *priorvector, double BF21, int p, gsl_vecto
 						gsl_vector *dimension_prob,
 						int k2, gsl_vector *hatbetap, gsl_vector *meanhatbetap, 
 						gsl_matrix *joint_incl_prob);
-int my_gsl_matrix_fprintf(FILE *stream,gsl_matrix *m,char *fmt);
+int my_gsl_matrix_fprintf(FILE *stream,gsl_matrix *m);
 int my_gsl_vector_fprintf(FILE *stream,gsl_vector *v,char *fmt);
 int gsl_vector_mifrac(gsl_vector *v, const double x);
 
